@@ -3,11 +3,12 @@
 from django.conf.urls import include
 from django.urls import re_path, reverse_lazy
 
-import core_curate_app.permissions.rights as rights
+from core_main_app.utils.decorators import permission_required
+from core_curate_app.permissions import rights
 import core_curate_app.views.user.ajax as user_ajax
 import core_curate_app.views.user.views as user_views
 from core_curate_app.views.common import views as common_views
-from core_main_app.utils.decorators import permission_required
+
 
 urlpatterns = [
     re_path(r"^$", user_views.index, name="core_curate_index"),
@@ -17,7 +18,8 @@ urlpatterns = [
         user_views.EnterDataView.as_view(),
         name="core_curate_enter_data",
     ),
-    # FIXME: url to allow reopening a form with unsaved changes (may be temporary until curate workflow redesign)
+    # FIXME: url to allow reopening a form with unsaved changes
+    #  (may be temporary until curate workflow redesign)
     re_path(
         r"^enter-data/(?P<curate_data_structure_id>\w+)/(?P<reload_unsaved_changes>\w+)$",
         user_views.EnterDataView.as_view(),
@@ -64,8 +66,8 @@ urlpatterns = [
     re_path(
         r"^view-form/(?P<curate_data_structure_id>\w+)$",
         permission_required(
-            content_type=rights.curate_content_type,
-            permission=rights.curate_access,
+            content_type=rights.CURATE_CONTENT_TYPE,
+            permission=rights.CURATE_ACCESS,
             login_url=reverse_lazy("core_main_app_login"),
         )(common_views.FormView.as_view()),
         name="core_curate_view_form",
