@@ -1,9 +1,9 @@
 """ Fixtures files for Data Structure
 """
-from core_curate_app.components.curate_data_structure.models import CurateDataStructure
-from core_main_app.components.template.models import Template
 from core_main_app.components.data.models import Data
+from core_main_app.components.template.models import Template
 from core_main_app.utils.integration_tests.fixture_interface import FixtureInterface
+from core_curate_app.components.curate_data_structure.models import CurateDataStructure
 
 
 class DataStructureFixtures(FixtureInterface):
@@ -36,19 +36,23 @@ class DataStructureFixtures(FixtureInterface):
         # NOTE: no xml_content to avoid using unsupported GridFS mock
         self.data = Data(
             template=self.template, user_id="1", dict_content=None, title="title"
-        ).save()
+        )
+        self.data.save()
 
         self.data_structure_1 = CurateDataStructure(
             user="1", template=self.template, name="data_structure_1", data=self.data
-        ).save()
+        )
+        self.data_structure_1.save()
 
         self.data_structure_2 = CurateDataStructure(
             user="1", template=self.template, name="data_structure_2"
-        ).save()
+        )
+        self.data_structure_2.save()
 
         self.data_structure_3 = CurateDataStructure(
             user="2", template=self.template, name="data_structure_3"
-        ).save()
+        )
+        self.data_structure_3.save()
 
         self.data_collection = [
             self.data_structure_1,
@@ -63,12 +67,12 @@ class DataStructureFixtures(FixtureInterface):
         Returns:
 
         """
-        template = Template()
+        self.template = Template()
         xsd = (
             '<xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">'
             '<xs:element name="tag"></xs:element></xs:schema>'
         )
-        template.content = xsd
-        template.hash = ""
-        template.filename = "filename"
-        self.template = template.save()
+        self.template.content = xsd
+        self.template.hash = ""
+        self.template.filename = "filename"
+        self.template.save()
